@@ -105,10 +105,10 @@ public:
 
         QString windowId;
         if (widget) {
-            widget->winId(); // ensure we have a handle so we can export a window (without this windowHandle() may be null)
+            widget->window()->winId(); // ensure we have a handle so we can export a window (without this windowHandle() may be null)
             auto services = QGuiApplicationPrivate::platformIntegration()->services();
             if (auto unixServices = dynamic_cast<QGenericUnixServices *>(services)) {
-                windowId = unixServices->portalWindowIdentifier(widget->windowHandle());
+                windowId = unixServices->portalWindowIdentifier(widget->window()->windowHandle());
             }
         }
 
@@ -488,6 +488,7 @@ void KdePlatformTheme::setQtQuickControlsTheme()
         if (qgetenv("QT_QUICK_CONTROLS_1_STYLE").right(7) == "Desktop") {
             qunsetenv("QT_QUICK_CONTROLS_1_STYLE");
         }
+        QQuickStyle::setStyle(QLatin1String("org.kde.breeze"));
         return;
     }
     // if the user has explicitly set something else, don't meddle
